import { AccessLevelList } from '../shared/access-level';
import { PolicyStatement } from '../shared';
import { aws_iam as iam } from "aws-cdk-lib";
/**
 * Statement provider for service [aws-cloud-control-api](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscloudcontrolapi.html).
 *
 * @param sid [SID](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_sid.html) of the statement
 */
export declare class AwsCloudControlApi extends PolicyStatement {
    servicePrefix: string;
    /**
     * Grants permission to cancel resource requests in your account
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/cloudcontrolapi/latest/APIReference/API_CancelResourceRequest.html
     */
    toCancelResourceRequest(): this;
    /**
     * Grants permission to create resources in your account
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/cloudcontrolapi/latest/APIReference/API_CreateResource.html
     */
    toCreateResource(): this;
    /**
     * Grants permission to delete resources in your account
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/cloudcontrolapi/latest/APIReference/API_DeleteResource.html
     */
    toDeleteResource(): this;
    /**
     * Grants permission to get resources in your account
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/cloudcontrolapi/latest/APIReference/API_GetResource.html
     */
    toGetResource(): this;
    /**
     * Grants permission to get resource requests in your account
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/cloudcontrolapi/latest/APIReference/API_GetResourceRequestStatus.html
     */
    toGetResourceRequestStatus(): this;
    /**
     * Grants permission to list resource requests in your account
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/cloudcontrolapi/latest/APIReference/API_ListResourceRequests.html
     */
    toListResourceRequests(): this;
    /**
     * Grants permission to list resources in your account
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/cloudcontrolapi/latest/APIReference/API_ListResources.html
     */
    toListResources(): this;
    /**
     * Grants permission to update resources in your account
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/cloudcontrolapi/latest/APIReference/API_UpdateResource.html
     */
    toUpdateResource(): this;
    protected accessLevelList: AccessLevelList;
    /**
     * Statement provider for service [aws-cloud-control-api](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awscloudcontrolapi.html).
     *
     */
    constructor(props?: iam.PolicyStatementProps);
}
